The Deriver extension - Betty 0.4.0a3 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# The Deriver extension

The `betty.extension.Deriver` extension derives, or infers, events for people based on their existing events. For example, we know that someone’s final disposition, such as a burial or cremation, comes after their death. If a person has a burial event without a date, and a death event with a date of January 1, 1970, the Deriver will update the burial event with the date range sometime after January 1, 1970.

The Deriver works for every event type that declares it can be derived, and depending on which other event types it declares it comes before or after. This means that the behavior of this extension is complex, and dependent on the event types used within your site as well as the existing events for each person.

Enable this extension in your project’s configuration file as follows:

YAML

    extensions:
      betty.extension.Deriver: {}

JSON

    {
      "extensions": {
        "betty.extension.Deriver": {}
      }
    }

## Configuration

This extension is not configurable.